@@ -57,7 +57,11 @@ sub _new {
 							       $params{wwpn},
 							       $params{flags});
     } elsif (exists $params{xml}) {
-	$self = Sys::Virt::NodeDevice::_create_xml($con, $params{xml});
+	if ($params{nocreate}) {
+	    $self = Sys::Virt::NodeDevice::_define_xml($con, $params{xml}, $params{flags});
+	} else {
+	    $self = Sys::Virt::NodeDevice::_create_xml($con, $params{xml}, $params{flags});
+	}
     } else {
 	die "name parameter is required";
     }
@@ -95,6 +99,18 @@ Unbind the node device from the host OS device driver
 Reset the node device. The device must be unbound from the host
 OS drivers for this to work
 
+=item $dev->create($flags=0)
+
+Start a node device whose configuration was previously defined using the
+C<define_node_device> method in L<Sys::Virt>. The C<$flags> parameter is
+currently unused and defaults to zero.
+
+=item $dev->undefine($flags=0)
+
+Delete a node device whose configuration was previously defined using the
+C<define_node_device> method in L<Sys::Virt>. The C<$flags> parameter is
+currently unused and defaults to zero.
+
 =item $dev->destroy()
 
 Destroy the virtual device releasing any OS resources associated
@@ -201,6 +217,14 @@ Include s390 AP matrix devices
 
 Include s390 AP queue devices
 
+=item Sys::Virt::NodeDevice::LIST_ACTIVE
+
+Include active devices
+
+=item Sys::Virt::NodeDevice::LIST_INACTIVE
+
+Include inactive devices
+
 =back
 
 =head2 EVENT ID CONSTANTS
@@ -233,6 +257,14 @@ Indicates that a device was created
 
 Indicates that a device has been deleted
 
+=item Sys::Virt::NodeDevice::EVENT_DEFINED
+
+Indicates that a device configuration has been created
+
+=item Sys::Virt::NodeDevice::EVENT_UNDEFINED
+
+Indicates that a device configuration has been deleted
+
 =back
 
 =cut
